      program lj
c*************************************************
c     Molecular Dynamics simulation for 
c         Lennard-Jones potential
c     All values are transformed to non-dimensional values
c     University of Tokyo, S. Izumi (2003)
c*************************************************
      include 'para.inc'
c      parameter(im=256,dt=0.1,npoten=0) !LJ
      parameter(im=128,dt=0.01,npoten=1)  !FS
c   coordination of atoms
      dimension x(im),y(im),z(im)
c   weight of atoms
      dimension wm(im)
c   velocity
      dimension vx(im),vy(im),vz(im)
c   interatomic force
      dimension fx(im),fy(im),fz(im)
c   stress (x,xy,y)
      dimension stress(6)
c   atomic stress
      dimension pl(6,im)
c   Atomic energy
      dimension uk(im)
c   Setting of calulation range (kc: bond information)
c    kc(i,1) : 1st booking atom 
c    kc(i,2) : 2nd booking atom 
c    kc(i,3) : boundary condition of x-direction (-1 or 0 or 1) 
c    kc(i,4) : boundary condition of y-direction (-1 or 0 or 1) 
c    kc(i,5) : boundary condition of z-direction (-1 or 0 or 1) 
      dimension kc(kc1,kc2)
c
c********************************************************************
c   xj, yj, zj : Center of gravity
c   xl, yl, zl : Cell size
c   t, tf  : Present and setting temperatures
c   ik     : total number of bonds
c   nn     : total number of steps
c   n      : present step
c   pset   : setting pressure
c   dk     : degree of cell weight
c   utot   : total energy
c********************************************************************
c   animation
      open(1,file='xy.dat')
c   physical values
      open(2,file='values.dat')
c   initial coordination
      open(8,file='posi.dat')
c   final coordination
      open(9,file='initdata.dat')
c   setting file (number of steps, etc.)
c     open(10,file='number.dat')
c   final atomic force
      open(20,file='initf.dat')
c   initial atomic force
      open(21,file='pforce.dat')
c  total MD steps
      nn = 100000
c  average interval for cell adjustment
      nadj=1000
c  average interval for book-keeping
      nbook=100
c  average interval for animation
      nanime=100
c  average interval for output of physical values
      nout=100
c  setting pressure
      pset=0.0d0
c  degree of cell weight
      dk=1.0d0
c  setting initial tempearature (non-dimensional)
      tf_real = 10.0d0
      tf=10.0d0*blz/ev ! non-dimentional temp.      
c
      if (npoten.eq.0) then
c  setting cutoff distance (LJ:3.504*4.5;FS:36.0d0)
      rcut =3.504d0*4.5d0
c  setting atomic weight  (6.645d0:Ar)
      do i = 1,im
         wm(i)=6.645d0
      enddo
      endif
      if (npoten.eq.1) then
c  setting cutoff distance (LJ:3.504*4.5;FS:36.0d0)
      rcut =3.569745d0*1.2d0
c  setting atomic weight  (6.645d0:Ar)
      do i = 1,im
         wm(i)=55.8473d0
      enddo
      endif
c
c***** read from posi.dat
      read(8,*)i11,i22,i33
      read(8,*)xl,yl,zl
      read(8,*)d1,d2
      do 50 i=1,im
        read(8,1010)x(i),y(i),z(i),vx(i),vy(i),vz(i)
        read(21,1011)fx(i),fy(i),fz(i)
 50   continue
c
 1010 format(6(e21.13))
 1011 format(3(e21.13))
      call temp(im,vx,vy,vz,wm,t)
c*********************************
c  book-keeping
      call pcopyf(im,n,ik,kc,x,y,z,xl,yl,zl,rcut,dt)
c******** main loop start!! *********
      do 1 n=1,nn
c  potential calculation and finite difference method
      if (npoten.eq.0) call calcu
     &(im,ik,kc,x,y,z,vx,vy,vz,fx,fy,fz,wm,pl,uk,xl,yl,zl,dt)
      if (npoten.eq.1) call calcu_FS
     &(im,ik,kc,x,y,z,vx,vy,vz,fx,fy,fz,wm,pl,uk,xl,yl,zl,dt)
c  temperature
      call temp(im,vx,vy,vz,wm,t)
c  stress
      call press(im,vx,vy,vz,pl,stress,xl,yl,zl)
c  adjustment of temperature
c      call tadj(im,vx,vy,vz,t,tf)
c  adjust cell size (no support)
c     call cell_adj(im,n,nadj,x,y,z,stress,xl,yl,zl,dk,pset)
c  calculate energy
      call energy(im,uk,utot,t)
c  correction of translational velocity
      call heishin(im,vx,vy,vz)
c
      if (mod(n,nbook).eq.0) then
c  for book-keeping
      call pcopyf(im,n,ik,kc,x,y,z,xl,yl,zl,rcut,dt)
      endif
c
      if (mod(n,nanime).eq.0) then
c  for animation
      call out(im,x,y,z,xl,yl,zl,nanime,nn)
      endif
c
      if (mod(n,nout).eq.0) then
c  for output
      write(2,1123)n,t,utot,stress(1),stress(2),stress(3)
      endif
      write(6,1123)n,t,utot,stress(1),stress(2),stress(3)
 1123 format(i7,5e15.7)
c
 1    continue
c
c output final state
      write(9,*)0,im,1
      write(9,1011)xl,yl,zl
      write(9,*)d1,d2
      do 10 i=1,im
         write(9,1010)x(i),y(i),z(i),vx(i),vy(i),vz(i)
         write(20,1011)fx(i),fy(i),fz(i)
 10   continue
c
      stop
      end






